You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@pdfbox.apache.org by "Tim Allison (Jira)" <ji...@apache.org> on 2026/09/16 13:00:00 UTC
[jira] [Updated] (PDFBOX-6268) Avoid rebuilding key cache when possible
[ https://issues.apache.org/jira/browse/PDFBOX-6268?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel ]
Tim Allison updated PDFBOX-6268:
--------------------------------
Attachment: RFFQRH5P3P4YLUL5MWWZIPDQRKAPES2H.pdf
G7BO7PNCCREVF2BCY5YSYOPYDLMBYASY.pdf
> Avoid rebuilding key cache when possible
> ----------------------------------------
>
> Key: PDFBOX-6268
> URL: https://issues.apache.org/jira/browse/PDFBOX-6268
> Project: PDFBox
> Issue Type: Task
> Components: Parsing
> Reporter: Tim Allison
> Priority: Minor
> Attachments: G7BO7PNCCREVF2BCY5YSYOPYDLMBYASY.pdf, RFFQRH5P3P4YLUL5MWWZIPDQRKAPES2H.pdf
>
>
> Over on Tika, we found that our {{COSDocument.getObjectsByType(FILESPEC)}} was really expensive on a couple of PDFs.
> The issue was that every object stream parse rebuilds the cache from scratch: xref entries × object streams map insertions.
> With incoming PR, we could get >600s -> ~4 seconds or less.
--
This message was sent by Atlassian Jira
(v8.20.10#820010)
---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@pdfbox.apache.org
For additional commands, e-mail: dev-help@pdfbox.apache.org